require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xremotefile',
  dscmeta_resource_friendly_name: 'xRemoteFile',
  dscmeta_resource_name: 'DSC_xRemoteFile',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xPSDesiredStateConfiguration',
  dscmeta_module_version: '9.1.0',
  docs: 'The DSC xRemoteFile resource type.
         Automatically generated from version 9.1.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_proxy: {
      type: 'Optional[String]',
      desc: "Uses a proxy server for the request, rather than connecting directly to the Internet resource. Should be the URI of a network proxy server (e.g 'http://10.20.30.1').",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_proxycredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Specifies a user account that has permission to use the proxy server that is specified by the Proxy parameter.',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Specifies a user account that has permission to send the request.',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_checksum: {
      type: 'Optional[String]',
      desc: 'Specifies the checksum value to compare against the downloaded file',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Says whether DestinationPath exists on the machine.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_destinationpath: {
      type: 'String',
      desc: 'Path under which downloaded or copied file should be accessible after operation.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_checksumtype: {
      type: "Optional[Enum['None', 'SHA1', 'SHA256', 'SHA384', 'SHA512', 'MACTripleDES', 'MD5', 'RIPEMD160']]",
      desc: 'Specifies the checksum type to verify the downloaded file',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_headers: {
      type: 'Optional[Array[Struct[{
              key => Optional[String],
              value => Optional[String],
            }]]]',
      desc: 'Headers of the web request.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_KeyValuePair[]',
      mof_is_embedded: true,
    },
    dsc_uri: {
      type: 'String',
      desc: 'Uri of a file which should be copied or downloaded. This parameter supports HTTP and HTTPS values.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_timeoutsec: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies how long the request can be pending before it times out.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_useragent: {
      type: 'Optional[String]',
      desc: 'User agent for the web request.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_matchsource: {
      type: 'Optional[Boolean]',
      desc: 'A boolean value to indicate whether the remote file should be re-downloaded if the file in the DestinationPath was modified locally. The default value is true.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
